@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.42'; # VERSION
+our $VERSION = '1.43'; # VERSION
 
 our %SPEC;
 
@@ -18,7 +18,7 @@ $SPEC{cat} = {
     args => {
         %common_args,
     },
-    tags => [qw/filtering/],
+    tags => [qw/filtering itemfunc/],
 };
 sub cat {
     my %args = @_;
@@ -31,6 +31,10 @@ sub cat {
     [200, "OK"];
 }
 
+sub _cat_item {
+    $_[0];
+}
+
 1;
 # ABSTRACT: Pass input unchanged
 
@@ -38,7 +42,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -46,14 +50,14 @@ Data::Unixish::cat - Pass input unchanged
 
 =head1 VERSION
 
-version 1.42
+version 1.43
 
 =head1 SYNOPSIS
 
 In Perl:
 
- use Data::Unixish::List qw(dux);
- my @res = dux("cat", 1, 2, 3, 4); # => (1, 2, 3, 4)
+ use Data::Unixish qw(lduxl);
+ my @res = lduxl("cat", 1, 2, 3, 4); # => (1, 2, 3, 4)
 
 In command line:
 
@@ -62,15 +66,13 @@ In command line:
  2
  3
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 cat(%args) -> [status, msg, result, meta]
 
+Pass input unchanged.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -87,7 +89,14 @@ Output stream (e.g. array or filehandle).
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 =head1 SEE ALSO
 
@@ -103,8 +112,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -116,7 +124,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
