@@ -9,7 +9,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.42'; # VERSION
+our $VERSION = '1.43'; # VERSION
 
 our %SPEC;
 
@@ -24,10 +24,13 @@ _
     args => {
         %common_args,
         callback => {
-            summary => 'The callback coderef or regexp to use',
+            summary => 'The callback code or regexp to use',
+            schema  => ['any*' => of => ['str*', 're*', 'code*']],
+            req     => 1,
+            pos     => 0,
         },
     },
-    tags => [qw//],
+    tags => [qw/filtering perl unsafe/],
 };
 sub grep {
     my %args = @_;
@@ -36,6 +39,9 @@ sub grep {
     if (ref($callback) eq ref(qr{})) {
         my $re = $callback;
         $callback = sub { $_ =~ $re };
+    } elsif (ref($callback) ne 'CODE') {
+        $callback = eval "sub { $callback }";
+        die "invalid code for grep: $@" if $@;
     }
 
     local ($., $_);
@@ -53,7 +59,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -61,34 +67,39 @@ Data::Unixish::grep - Perl grep
 
 =head1 VERSION
 
-version 1.42
+version 1.43
 
 =head1 SYNOPSIS
 
 In Perl:
 
- use Data::Unixish::List qw(dux);
- my @res = dux([grep => {callback => sub { $_ % 2 }}], 1, 2, 3, 4, 5);
+ use Data::Unixish qw(lduxl);
+ my @res = lduxl([grep => {callback => sub { $_ % 2 }}], 1, 2, 3, 4, 5);
  # => (1, 3, 5)
 
-=head1 DESCRIPTION
+In command-line:
+
+ % echo -e "1\n2\n3\n4\n5" | dux grep '$_ % 2'
+ 1
+ 3
+ 5
 
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 grep(%args) -> [status, msg, result, meta]
 
+Perl grep.
+
 Filter each item through a callback.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<callback> => I<any>
+=item * B<callback>* => I<code|re|str>
 
-The callback coderef or regexp to use.
+The callback code or regexp to use.
 
 =item * B<in> => I<any>
 
@@ -102,7 +113,14 @@ Output stream (e.g. array or filehandle).
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 =head1 SEE ALSO
 
@@ -118,8 +136,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -131,7 +148,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
