@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.42'; # VERSION
+our $VERSION = '1.43'; # VERSION
 
 our %SPEC;
 
@@ -30,24 +30,27 @@ _
             pos     => 0,
         },
     },
-    tags => [qw/text/],
+    tags => [qw/text itemfunc/],
 };
 sub rins {
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
-    my $text = $args{text};
 
     while (my ($index, $item) = each @$in) {
-        if (defined($item) && !ref($item)) {
-            $item =~ s/$/$text/mg;
-        }
-
-        push @$out, $item;
+        push @$out, _rins_item($item, \%args);
     }
 
     [200, "OK"];
 }
 
+sub _rins_item {
+    my ($item, $args) = @_;
+    if (defined($item) && !ref($item)) {
+        $item =~ s/$/$args->{text}/mg;
+    }
+    return $item;
+}
+
 1;
 # ABSTRACT: Add some text at the end of each line of text
 
@@ -55,7 +58,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -63,7 +66,7 @@ Data::Unixish::rins - Add some text at the end of each line of text
 
 =head1 VERSION
 
-version 1.42
+version 1.43
 
 =head1 SYNOPSIS
 
@@ -79,15 +82,13 @@ In command line:
  1xx
  2 xx
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 rins(%args) -> [status, msg, result, meta]
 
+Add some text at the end of each line of text.
+
 This is sort of a counterpart for rtrim, which removes whitespace at the end
 (right) of each line of text.
 
@@ -111,7 +112,14 @@ The text to add.
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 =head1 SEE ALSO
 
@@ -127,8 +135,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -140,7 +147,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
