@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.42'; # VERSION
+our $VERSION = '1.43'; # VERSION
 
 our %SPEC;
 
@@ -26,26 +26,29 @@ _
             cmdline_aliases => { nl=>{} },
         },
     },
-    tags => [qw/text/],
+    tags => [qw/text itemfunc/],
 };
 sub rtrim {
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
-    my $nl  = $args{strip_newline} // 0;
 
     while (my ($index, $item) = each @$in) {
-        my @lt;
-        if (defined($item) && !ref($item)) {
-            $item =~ s/[\r\n]+\z// if $nl;
-            $item =~ s/[ \t]+$//mg;
-        }
-
-        push @$out, $item;
+        push @$out, _rtrim_item($item, \%args);
     }
 
     [200, "OK"];
 }
 
+sub _rtrim_item {
+    my ($item, $args) = @_;
+
+    if (defined($item) && !ref($item)) {
+        $item =~ s/[\r\n]+\z// if $args->{strip_newline};
+        $item =~ s/[ \t]+$//mg;
+    }
+    return $item;
+}
+
 1;
 # ABSTRACT: Strip whitespace at the end of each line of text
 
@@ -53,7 +56,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -61,14 +64,14 @@ Data::Unixish::rtrim - Strip whitespace at the end of each line of text
 
 =head1 VERSION
 
-version 1.42
+version 1.43
 
 =head1 SYNOPSIS
 
 In Perl:
 
- use Data::Unixish::List qw(dux);
- my @res = dux('rtrim', "x", "a   ", "b \nc  \n", undef, ["d "]);
+ use Data::Unixish qw(lduxl);
+ my @res = lduxl('rtrim', "x", "a   ", "b \nc  \n", undef, ["d "]);
  # => ("x", "a", "b\nc\n", undef, ["d "])
 
 In command line:
@@ -77,15 +80,13 @@ In command line:
  x
  a
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 rtrim(%args) -> [status, msg, result, meta]
 
+Strip whitespace at the end of each line of text.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -106,7 +107,14 @@ Whether to strip newlines at the end of text.
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 =head1 HOMEPAGE
 
@@ -118,8 +126,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -131,7 +138,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
