@@ -12,7 +12,7 @@ use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 use Text::sprintfn ();
 
-our $VERSION = '1.42'; # VERSION
+our $VERSION = '1.43'; # VERSION
 
 our %SPEC;
 
@@ -42,12 +42,23 @@ _
             schema=>[bool => default=>0],
         },
     },
-    tags => [qw/format/],
+    tags => [qw/format itemfunc/],
 };
 sub sprintfn {
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
-    my $format = $args{format};
+
+    my $orig_locale = _sprintfn_begin(\%args);
+    while (my ($index, $item) = each @$in) {
+        push @$out, _sprintfn_item($item, \%args);
+    }
+    _sprintfn_end(\%args, $orig_locale);
+
+    [200, "OK"];
+}
+
+sub _sprintfn_begin {
+    my $args = shift;
 
     my $orig_locale = setlocale(LC_ALL);
     if ($ENV{LC_NUMERIC}) {
@@ -57,35 +68,39 @@ sub sprintfn {
     } elsif ($ENV{LANG}) {
         setlocale(LC_ALL, $ENV{LANG});
     }
+    return $orig_locale;
+}
 
-    while (my ($index, $item) = each @$in) {
+sub _sprintfn_item {
+    my ($item, $args) = @_;
+
+    {
+        last unless defined($item);
+        my $r = ref($item);
+        if ($r eq 'ARRAY' && !$args->{skip_array}) {
+            no warnings;
+            $item = Text::sprintfn::sprintfn($args->{format}, @$item);
+            last;
+        }
+        if ($r eq 'HASH' && !$args->{skip_hash}) {
+            no warnings;
+            $item = Text::sprintfn::sprintfn($args->{format}, $item);
+            last;
+        }
+        last if $r;
+        last if $item eq '';
+        last if !looks_like_number($item) && $args->{skip_non_number};
         {
-            last unless defined($item);
-            my $r = ref($item);
-            if ($r eq 'ARRAY' && !$args{skip_array}) {
-                no warnings;
-                $item = Text::sprintfn::sprintfn($format, @$item);
-                last;
-            }
-            if ($r eq 'HASH' && !$args{skip_hash}) {
-                no warnings;
-                $item = Text::sprintfn::sprintfn($format, $item);
-                last;
-            }
-            last if $r;
-            last if $item eq '';
-            last if !looks_like_number($item) && $args{skip_non_number};
-            {
-                no warnings;
-                $item = Text::sprintfn::sprintfn($format, $item);
-            }
+            no warnings;
+            $item = Text::sprintfn::sprintfn($args->{format}, $item);
         }
-        push @$out, $item;
     }
+    return $item;
+}
 
+sub _sprintfn_end {
+    my ($args, $orig_locale) = @_;
     setlocale(LC_ALL, $orig_locale);
-
-    [200, "OK"];
 }
 
 1;
@@ -95,7 +110,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -103,25 +118,23 @@ Data::Unixish::sprintfn - Like sprintf, but use sprintfn() from Text::sprintfn
 
 =head1 VERSION
 
-version 1.42
+version 1.43
 
 =head1 SYNOPSIS
 
 In Perl:
 
- use Data::Unixish::List qw(dux);
- my @res = dux([sprintfn => {format=>"%(n).1f"}], {n=>1}, {n=>2}, "", undef);
+ use Data::Unixish qw(lduxl);
+ my @res = lduxl([sprintfn => {format=>"%(n).1f"}], {n=>1}, {n=>2}, "", undef);
  # => ("1.0", "2.0", "", undef)
 
-=head1 DESCRIPTION
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 sprintfn(%args) -> [status, msg, result, meta]
 
+Like sprintf, but use sprintfn() from Text::sprintfn.
+
 Unlike in I<sprintf>, with this function, hash will also be processed.
 
 Arguments ('*' denotes required arguments):
@@ -148,7 +161,14 @@ Output stream (e.g. array or filehandle).
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 =head1 SEE ALSO
 
@@ -164,8 +184,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -177,7 +196,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
